# Table of Contents

- [ai-agent-modeling-guidelines](<./ai-agent-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [AI Agent Modeling Guidelines](<./AI-Agent-Modeling-Guidelines.md>)
  - [Definition](<./AI-Agent-Modeling-Guidelines/Definition.md>)
  - [Description](<./AI-Agent-Modeling-Guidelines/Description.md>)
  - [Modeling Guidelines](<./AI-Agent-Modeling-Guidelines/Modeling-Guidelines.md>)
  - [Best Practices](<./AI-Agent-Modeling-Guidelines/Best-Practices.md>)
  - [Antipatterns](<./AI-Agent-Modeling-Guidelines/Antipatterns.md>)
  - [Related Information](<./AI-Agent-Modeling-Guidelines/Related-Information.md>)
